chiark / gitweb /
Change licensing conditions to LGPL.
authormdw <mdw>
Wed, 5 May 1999 18:52:45 +0000 (18:52 +0000)
committermdw <mdw>
Wed, 5 May 1999 18:52:45 +0000 (18:52 +0000)
.links
.skelrc
Makefile.am
cancel.c
cancel.h
configure.in
mdwfocus.c
mdwfocus.h
msg.c
msg.h

diff --git a/.links b/.links
index 10f134c8cd0e7f687c86b57af6a89c7ff0c89db0..251e82ed87716ecaf70957905416b97385dd52a4 100644 (file)
--- a/.links
+++ b/.links
@@ -1,4 +1,4 @@
-COPYING
+COPYING.LIB
 install-sh
 missing
 mkinstalldirs
diff --git a/.skelrc b/.skelrc
index 235e96e4ac42b9f4650557016963c19aa1b22f34..e491163917edfd59d5a21cf8d2b98c8315b94b02 100644 (file)
--- a/.skelrc
+++ b/.skelrc
@@ -4,5 +4,6 @@
       (append
        '((author . "Straylight/Edgeware")
         (full-title . "the mgLib GTK utilities library")
+        (licence-text . skelrc-lgpl)
         (program . "mgLib"))
        skel-alist))
index ed1d72326303a86a5dd474b24dab4531029bcc13..a4b26c08a1d91e0182531692e1be5a085578e368 100644 (file)
@@ -1,6 +1,6 @@
 ## -*-makefile-*-
 ##
-## $Id: Makefile.am,v 1.2 1998/12/21 16:29:29 mdw Exp $
+## $Id: Makefile.am,v 1.3 1999/05/05 18:52:45 mdw Exp $
 ##
 ## Makefile for mgLib
 ##
 ## This file is part of the mgLib GTK utilities library.
 ##
 ## mgLib is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## it under the terms of the GNU Library General Public License as
+## published by the Free Software Foundation; either version 2 of the
+## License, or (at your option) any later version.
 ## 
 ## mgLib is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## GNU Library General Public License for more details.
 ## 
-## You should have received a copy of the GNU General Public License
-## along with mgLib; if not, write to the Free Software Foundation,
-## Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+## You should have received a copy of the GNU Library General Public
+## License along with mgLib; if not, write to the Free Software
+## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 ##----- Revision history ----------------------------------------------------
 ##
 ## $Log: Makefile.am,v $
+## Revision 1.3  1999/05/05 18:52:45  mdw
+## Change licensing conditions to LGPL.
+##
 ## Revision 1.2  1998/12/21 16:29:29  mdw
 ## Install the include files properly.
 ##
index d29b823b82c9e56001b0b6de6da5af3228f50d05..5c41fc5be2d8f5d05ca7879954856d74c0c9ce1a 100644 (file)
--- a/cancel.c
+++ b/cancel.c
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: cancel.c,v 1.2 1999/03/25 23:36:07 mdw Exp $
+ * $Id: cancel.c,v 1.3 1999/05/05 18:52:45 mdw Exp $
  *
  * Handle Escape keypresses, directing them to cancel buttons
  *
  * This file is part of the mgLib GTK utilities library.
  *
  * mgLib is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  * 
  * mgLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
- * along with mgLib; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with mgLib; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: cancel.c,v $
+ * Revision 1.3  1999/05/05 18:52:45  mdw
+ * Change licensing conditions to LGPL.
+ *
  * Revision 1.2  1999/03/25 23:36:07  mdw
  * Compile to nothing in absence of GTK, for the benefit of parent packages
  * which contain non-GTK-dependent parts.
index aa78df60abc214d10ba825f4829e0629178c46bd..88e0d05a8d7fda456ad326d8b3ae0fde596fc2d5 100644 (file)
diff --git a/msg.c b/msg.c
index 08a02851248054ef99c8b412fd5074ab2492048b..cbfede111f189429f8fe43035e2e816d33d2212c 100644 (file)
--- a/msg.c
+++ b/msg.c
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: msg.c,v 1.4 1999/04/29 20:48:13 mdw Exp $
+ * $Id: msg.c,v 1.5 1999/05/05 18:52:45 mdw Exp $
  *
  * Display a message and get an answer
  *
  * This file is part of the mgLib GTK utilities library.
  *
  * mgLib is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  * 
  * mgLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
- * along with mgLib; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with mgLib; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: msg.c,v $
+ * Revision 1.5  1999/05/05 18:52:45  mdw
+ * Change licensing conditions to LGPL.
+ *
  * Revision 1.4  1999/04/29 20:48:13  mdw
  * Add documentation for `msg'.
  *
diff --git a/msg.h b/msg.h
index 9f7e825a8018d632c2e4e87147f6e34b056f2a57..31ba0de6a5dbdd9b67af5c85e3da74afc44073d8 100644 (file)
--- a/msg.h
+++ b/msg.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: msg.h,v 1.2 1999/04/29 20:48:13 mdw Exp $
+ * $Id: msg.h,v 1.3 1999/05/05 18:52:45 mdw Exp $
  *
  * Display a message and get an answer
  *
  * This file is part of the mgLib GTK utilities library.
  *
  * mgLib is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  * 
  * mgLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License
- * along with mgLib; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with mgLib; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: msg.h,v $
+ * Revision 1.3  1999/05/05 18:52:45  mdw
+ * Change licensing conditions to LGPL.
+ *
  * Revision 1.2  1999/04/29 20:48:13  mdw
  * Add documentation for `msg'.
  *
--- a/cancel.h
+++ b/cancel.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: cancel.h,v 1.1 1998/12/11 09:44:21 mdw Exp $
+ * $Id: cancel.h,v 1.2 1999/05/05 18:52:45 mdw Exp $
  *
  * Handle Escape keypresses, directing them to cancel buttons
  *
  * This file is part of the mgLib GTK utilities library.
  *
  * mgLib is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  * 
  * mgLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  * 
* You should have received a copy of the GNU General Public License
* along with mgLib; if not, write to the Free Software Foundation,
* Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: cancel.h,v $
+ * Revision 1.2  1999/05/05 18:52:45  mdw
+ * Change licensing conditions to LGPL.
+ *
  * Revision 1.1  1998/12/11 09:44:21  mdw
  * Initial version.
  *
index 4ed36432b1ceca0ba425efa1e05a7e2b32174bf8..25b9fb0287e9c663a50092e78398b90c35fb3cff 100644 (file)
@@ -1,6 +1,6 @@
 dnl -*-fundamental-*-
 dnl
-dnl $Id: configure.in,v 1.4 1999/03/25 23:36:08 mdw Exp $
+dnl $Id: configure.in,v 1.5 1999/05/05 18:52:45 mdw Exp $
 dnl
 dnl Configuration script for mgLib
 dnl
@@ -12,22 +12,25 @@ dnl
 dnl This file is part of the mgLib GTK utilities library.
 dnl
 dnl mgLib is free software; you can redistribute it and/or modify
-dnl it under the terms of the GNU General Public License as published by
-dnl the Free Software Foundation; either version 2 of the License, or
-dnl (at your option) any later version.
+dnl it under the terms of the GNU Library General Public License as
+dnl published by the Free Software Foundation; either version 2 of the
+dnl License, or (at your option) any later version.
 dnl 
 dnl mgLib is distributed in the hope that it will be useful,
 dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
 dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-dnl GNU General Public License for more details.
+dnl GNU Library General Public License for more details.
 dnl 
-dnl You should have received a copy of the GNU General Public License
-dnl along with mgLib; if not, write to the Free Software Foundation,
-dnl Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+dnl You should have received a copy of the GNU Library General Public
+dnl License along with mgLib; if not, write to the Free Software
+dnl Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 dnl ----- Revision history --------------------------------------------------
 dnl
 dnl $Log: configure.in,v $
+dnl Revision 1.5  1999/05/05 18:52:45  mdw
+dnl Change licensing conditions to LGPL.
+dnl
 dnl Revision 1.4  1999/03/25 23:36:08  mdw
 dnl Compile to nothing in absence of GTK, for the benefit of parent packages
 dnl which contain non-GTK-dependent parts.
index b238e503a2ba20d82f96432919e3d9611d7c1a04..4d08f0da0ce03f4e1318fec9eccc659fced1326b 100644 (file)
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: mdwfocus.c,v 1.2 1999/03/25 23:36:09 mdw Exp $
+ * $Id: mdwfocus.c,v 1.3 1999/05/05 18:52:45 mdw Exp $
  *
  * Tell my hacked `fvwm' to focus this window
  *
  * This file is part of the mgLib GTK utilities library.
  *
  * mgLib is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  * 
  * mgLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  * 
* You should have received a copy of the GNU General Public License
* along with mgLib; if not, write to the Free Software Foundation,
* Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: mdwfocus.c,v $
+ * Revision 1.3  1999/05/05 18:52:45  mdw
+ * Change licensing conditions to LGPL.
+ *
  * Revision 1.2  1999/03/25 23:36:09  mdw
  * Compile to nothing in absence of GTK, for the benefit of parent packages
  * which contain non-GTK-dependent parts.
index 06b7254ae563825e7c54f21ed69a302e7445a5bc..db10b312f843bf021cb049de65ef5cba1fbf8214 100644 (file)
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: mdwfocus.h,v 1.1 1998/12/11 09:44:21 mdw Exp $
+ * $Id: mdwfocus.h,v 1.2 1999/05/05 18:52:45 mdw Exp $
  *
  * Tell my hacked `fvwm' to focus this window
  *
  * This file is part of the mgLib GTK utilities library.
  *
  * mgLib is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Library General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  * 
  * mgLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  * 
* You should have received a copy of the GNU General Public License
* along with mgLib; if not, write to the Free Software Foundation,
* Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: mdwfocus.h,v $
+ * Revision 1.2  1999/05/05 18:52:45  mdw
+ * Change licensing conditions to LGPL.
+ *
  * Revision 1.1  1998/12/11 09:44:21  mdw
  * Initial version.
  *
@@ -1,6 +1,6 @@
  * 
- * You should have received a copy of the GNU General Public License
- * along with mgLib; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with mgLib; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
@@ -1,6 +1,6 @@
  * 
- * You should have received a copy of the GNU General Public License
- * along with mgLib; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with mgLib; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
@@ -1,6 +1,6 @@
  * 
- * You should have received a copy of the GNU General Public License
- * along with mgLib; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General Public
+ * License along with mgLib; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 